class Circuit:
    def __init__(self):
        self.path = None
        self.input_order = None
        self.output_order = None
        self.name = None
        self.ver_str = None
        self.synth_ver_str = None
        self.synth_path = None
        self.input_dict = None
        self.input_count = None
        self.output_dict = None
        self.output_count = None
        self.testbench_path = None
        self.results_path = None
        self.simulation_pattern = None
        self.simulation_output = None
